/*
 * LXImage-Qt - a simple and fast image viewer
 * Copyright (C) 2013  PCMan <pcman.tw@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "provider.h"

using namespace LxImage;

QPointer<QNetworkAccessManager> Provider::sManager;
int Provider::ref(0);

Provider::Provider(QObject *parent) : QObject(parent) {
    ++ref;
    if(!sManager) {
        sManager = new QNetworkAccessManager;
    }
}

Provider::~Provider() {
    --ref;
    if(ref == 0) {
        delete sManager;
    }
}
